.. image:: https://github.com/FlorianCHA/snakevir/blob/master/docs/source/_images/snakevir_logo_title.png?raw=true
   :alt: Snakevir Logo
   :align: center


|PythonVersions| |SnakemakeVersions| |Downloads|

About Snakevir
===============

|readthedocs|

**Homepage:** `https://snakevir.readthedocs.io/en/latest/ <https://snakevir.readthedocs.io/en/latest/index.html>`_

Snakevir is a workflow developed in snakemake that enables viral metagenomic analysis of short-read data. You can give your own parameters/database in the config.yaml file to customize the workflow for your own data.

Authors
======

* Florian CHARRIAT (CIRAD)
* Antoni Exbrayat (CIRAD)
* Etienne Loire (CIRAD)
* Serafin Gutierrez (CIRAD)

Thanks
======

Thanks to CulebrONT team’s.

The authors acknowledge the Cirad HPC (South Green Platform) from CIRAD Montpellier for providing HPC resources that contributed to this work. https://bioinfo-agap.cirad.fr/ - http://www.southgreen.fr

License
=======

Licencied under `CeCill-C <http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html>`_ and GPLv3.

Intellectual property belongs to `CIRAD <https://www.cirad.fr/>`_ and authors.

.. |PythonVersions| image:: https://img.shields.io/badge/python-≥3.6%2B-blue
   :target: https://www.python.org/downloads

.. |SnakemakeVersions| image:: https://img.shields.io/badge/snakemake-≥6.10.0-brightgreen.svg
   :target: https://snakemake.readthedocs.io

.. |readthedocs| image:: https://pbs.twimg.com/media/E5oBxcRXoAEBSp1.png
   :target: https://culebront-pipeline.readthedocs.io/en/latest/
   :width: 400px

.. |Downloads| image:: https://img.shields.io/badge/pypi-Snakevir-purple
   :target: https://pypi.org/project/snakevir
   :alt: PyPi downloads
